@@ -7,7 +7,8 @@ from power_dict.utils import DictUtils
 class GetStrDictPropertyTests(unittest.TestCase):
     properties = {
         "property_1": "Hello!",
-        "property_1_none": None
+        "property_1_none": None,
+        "property_1_empty": ''
     }
 
     def test_get_property(self):
@@ -19,6 +20,10 @@ class GetStrDictPropertyTests(unittest.TestCase):
         self.assertIsInstance(target, str)
         self.assertEqual(target, "Default string")
 
+        target = DictUtils.get_str_dict_property(self.properties, 'property_1_empty', default_value="Default string")
+        self.assertIsInstance(target, str)
+        self.assertEqual(target, "Default string")
+
         target = DictUtils.get_str_dict_property(self.properties, 'key_not_found')
         self.assertIsInstance(target, str)
         self.assertEqual(target, '')
@@ -32,5 +37,9 @@ class GetStrDictPropertyTests(unittest.TestCase):
             DictUtils.get_required_str_dict_property(self.properties, 'property_1_none',
                                                      required_error="Key property_1_none is None")
 
+            with self.assertRaises(NoneParameterError):
+                DictUtils.get_required_str_dict_property(self.properties, 'property_1_empty',
+                                                         required_error="Key property_1_none is None")
+
         with self.assertRaises(NoneParameterError):
             DictUtils.get_required_str_dict_property(self.properties, 'key_not_found')
